'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var PropTypes = _interopDefault(require('prop-types'));

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = "/* add css styles here (optional) */\n\n.styles_test__3OKZ1 {\n  display: inline-block;\n  margin: 2em auto;\n  border: 2px solid #000;\n  font-size: 2em;\n}\n";
var styles = { "test": "styles_test__3OKZ1" };
styleInject(css);

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var paths = {
  STAR: "M1024 397.050l-353.78-51.408-158.22-320.582-158.216 320.582-353.784 51.408 256 249.538-60.432 352.352 316.432-166.358 316.432 166.358-60.434-352.352 256.002-249.538zM512 753.498l-223.462 117.48 42.676-248.83-180.786-176.222 249.84-36.304 111.732-226.396 111.736 226.396 249.836 36.304-180.788 176.222 42.678 248.83-223.462-117.48z",
  STAR_FILLED: "M1024 397.050l-353.78-51.408-158.22-320.582-158.216 320.582-353.784 51.408 256 249.538-60.432 352.352 316.432-166.358 316.432 166.358-60.434-352.352 256.002-249.538z"
};

var StarRating = function (_Component) {
  inherits(StarRating, _Component);

  function StarRating(props) {
    classCallCheck(this, StarRating);

    var _this = possibleConstructorReturn(this, (StarRating.__proto__ || Object.getPrototypeOf(StarRating)).call(this, props));

    _this.mouseEnter = function (v) {
      if (_this.props.readOnly) return;
      _this.setState({ value: v });
    };

    _this.mouseLeave = function () {
      if (_this.props.readOnly) return;
      _this.setState({ value: _this.props.value });
    };

    _this.onClick = function (value) {
      if (_this.props.readOnly) return;
      if (_this.props.handleSelection) return _this.props.handleSelection(value);
    };

    _this.state = { value: _this.props.value };
    return _this;
  }

  createClass(StarRating, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          totalStars = _props.totalStars,
          starSize = _props.starSize;


      var styles = {
        svg: {
          display: "inline-block",
          verticalAlign: "middle",
          margin: (starSize || 32) / 8,
          cursor: this.props.readOnly ? "default" : "pointer"
        },
        path: {
          fill: this.props.color || "currentColor"
        }
      };

      var stars = Array.from(new Array(totalStars), function (x, index) {
        return index + 1;
      });

      return React__default.createElement(
        "div",
        { onMouseLeave: this.mouseLeave },
        stars.map(function (value, key) {
          return React__default.createElement(
            "svg",
            {
              onMouseEnter: function onMouseEnter() {
                return _this2.mouseEnter(value);
              },
              onClick: function onClick() {
                return _this2.onClick(value);
              },
              key: key,
              style: styles.svg,
              width: (starSize || 32) + "px",
              height: (starSize || 32) + "px",
              viewBox: "0 0 1024 1024",
              tooltip: value
            },
            React__default.createElement("path", {
              style: styles.path,
              d: value <= _this2.state.value ? paths.STAR_FILLED : paths.STAR
            })
          );
        })
      );
    }
  }]);
  return StarRating;
}(React.Component);

StarRating.propTypes = {
  totalStars: PropTypes.number,
  starSize: PropTypes.number,
  handleSelection: PropTypes.func,
  readOnly: PropTypes.bool,
  value: PropTypes.number.isRequired
};

StarRating.defaultProps = {
  totalStars: 5,
  starSize: 32,
  readOnly: false,
  value: 0
};

var ExampleComponent = function (_Component) {
  inherits(ExampleComponent, _Component);

  function ExampleComponent() {
    classCallCheck(this, ExampleComponent);
    return possibleConstructorReturn(this, (ExampleComponent.__proto__ || Object.getPrototypeOf(ExampleComponent)).apply(this, arguments));
  }

  createClass(ExampleComponent, [{
    key: "render",
    value: function render() {
      var text = this.props.text;


      return React__default.createElement(
        "div",
        { className: styles.test },
        "Example Component: ",
        text
      );
    }
  }]);
  return ExampleComponent;
}(React.Component);

ExampleComponent.propTypes = {
  text: PropTypes.string
};

exports.default = ExampleComponent;
exports.StarRating = StarRating;
//# sourceMappingURL=index.js.map
